/***************************************************************************
 $RCSfile: accountview.h,v $
                             -------------------
    cvs         : $Id: accountview.h,v 1.8 2006/01/11 13:15:50 aquamaniac Exp $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/



#ifndef KBANKING_ACCOUNTVIEW_H
#define KBANKING_ACCOUNTVIEW_H


#include "accountview.ui.h"


class AccountView;
class KBanking;


#include "accountlist.h"


class AccountView: public AccountViewUi {
  Q_OBJECT
public:
  AccountView(KBanking *kb,
              QWidget* parent=0, const char* name=0, WFlags fl=0);
  ~AccountView();

  bool init();
  bool fini();

protected:
  //void resizeEvent(QResizeEvent *e);

private:
  KBanking *_app;
  AccountListView *_accList;

  void _accountUpdate(bool forceTimeSpan);

protected slots:
  void slotUpdated();
  void slotDetails();
  void slotTransactions();
  void slotUpdate();
  void slotUpdateWithTimeSpan();

};










#endif /* KBANKING_ACCOUNTVIEW_H */



